@@ -18,10 +18,11 @@ def get_file_handler():
     return file_handler
 
 
-def get_logger(logger_name):
+def get_logger(logger_name, add_log_file=False):
     logger = logging.getLogger(logger_name)
     logger.setLevel(logging.INFO)
     logger.addHandler(get_console_handler())
-    logger.addHandler(get_file_handler())
+    if add_log_file:
+        logger.addHandler(get_file_handler())
     logger.propagate = False
     return logger
